@@ -475,8 +475,8 @@ def special_service(request, output):
     output['finish'] = True
 
 
-class WebSocketSever(tornado.websocket.WebSocketHandler):
-    opened_connections = {}
+class WebSocketHub(tornado.websocket.WebSocketHandler):
+    topic_connections = {}
 
     def open(self):
         pass
@@ -489,39 +489,43 @@ class WebSocketSever(tornado.websocket.WebSocketHandler):
             logging.error('WebSocket消息必须采用JSON格式！')
             return
 
-        if msg.get('type') == 'set_conn_id':
-            self.conn_id = msg.get('content')
-            if self.conn_id is not None:
-                old = self.opened_connections.get(self.conn_id)
-                if old is None:
-                    self.opened_connections[self.conn_id] = self
-                    logging.critical('WebSocket connection opened: {}'.format(self.conn_id))
-                    self.write_message({
-                        'type': 'welcome',
-                        'content': 'WebSocket connection opened: {}'.format(self.conn_id),
-                    })
+        if msg.get('type') == 'subscribe':
+            if getattr(self, 'topic', None) is not None:
+                logging.error('WebSocket已订阅过主题，不能更改！')
+                return
+
+            self.topic = msg.get('content')
+            if self.topic is not None:
+                connections = self.topic_connections.get(self.topic)
+                if connections is None:
+                    self.topic_connections[self.topic] = [self]
+                else:
+                    connections.append(self)
+                logging.critical('New WebSocket connection opened for topic: {}'.format(self.topic))
+                self.write_message({
+                    'type': 'welcome',
+                    'content': 'New WebSocket connection opened for topic: {}'.format(self.topic),
+                })
             else:
-                logging.error('WebSocket conn_id error')
+                logging.error('Invalid WebSocket topic : None')
                 self.close()
         else:
-            receiver = msg.get('receiver')
-            # 未指定receiver或receiver第一个字符为'/'
-            if receiver is None or receiver[0] == '/':
+            topic = msg.get('topic')
+            if topic is None:
                 return
-            if '/' in receiver:
-                i = receiver.find('/')
-                msg['receiver'] = receiver[i + 1:]
-                receiver = receiver[0: i]
-
             # 转发消息
-            next_websocket = self.opened_connections.get(receiver)
-            if next_websocket:
-                msg['sender'] = self.conn_id
-                next_websocket.write_message(msg)
+            connections = self.topic_connections.get(topic)
+            if isinstance(connections, list):
+                for conn in connections:
+                    conn.write_message(msg)
 
     def on_close(self):
-        self.opened_connections.pop(self.conn_id)
-        logging.critical('WebSocket connection closed: {}'.format(self.conn_id))
+        connections = self.topic_connections.get(self.topic)
+        if isinstance(connections, list):
+            connections.pop(connections.index(self))
+            if len(connections) == 0:
+                self.topic_connections.pop(self.topic)
+            logging.critical('WebSocket connection subscribed to topic: {} closed'.format(self.topic))
 
     def check_origin(self, origin):
         return True
@@ -600,7 +604,7 @@ def start():
         handlers = [
             (r'/management/health', HealthChecker),
             (r'/api/data', DataApi),
-            (r'/websocket', WebSocketSever),
+            (r'/websocket', WebSocketHub),
             (r'/(.*)', GatewayApi),
         ]
     else:
